/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudtrail.model.transform;

import java.util.Map;
import java.util.Map.Entry;
import java.math.*;
import java.nio.ByteBuffer;

import com.amazonaws.services.cloudtrail.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * ListPublicKeysResult JSON Unmarshaller
 */
public class ListPublicKeysResultJsonUnmarshaller implements
        Unmarshaller<ListPublicKeysResult, JsonUnmarshallerContext> {

    public ListPublicKeysResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        ListPublicKeysResult listPublicKeysResult = new ListPublicKeysResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.getCurrentToken();
        if (token == null)
            token = context.nextToken();
        if (token == VALUE_NULL)
            return null;

        while (true) {
            if (token == null)
                break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("PublicKeyList", targetDepth)) {
                    context.nextToken();
                    listPublicKeysResult
                            .setPublicKeyList(new ListUnmarshaller<PublicKey>(
                                    PublicKeyJsonUnmarshaller.getInstance())
                                    .unmarshall(context));
                }
                if (context.testExpression("NextToken", targetDepth)) {
                    context.nextToken();
                    listPublicKeysResult.setNextToken(context.getUnmarshaller(
                            String.class).unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null
                        || context.getLastParsedParentElement().equals(
                                currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth)
                        break;
                }
            }
            token = context.nextToken();
        }

        return listPublicKeysResult;
    }

    private static ListPublicKeysResultJsonUnmarshaller instance;

    public static ListPublicKeysResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new ListPublicKeysResultJsonUnmarshaller();
        return instance;
    }
}
